#include "EntityController.h"
#include <algorithm>
#include "ScoreController.h"
#include "StateCore.h"

EntityController::EntityController(StateCore &core)
	:
	core(core),
	aSpawnRate(0.5f),
	eSpawnRate(0.5f)
{
}

EntityController::~EntityController()
{
}

// Collision functions
void EntityController::CheckCollision(Entity *src1, Entity *src2)
{
	if (HasCollided(src1, src2))
	{
		src1->DoCollision(src2);
		src2->DoCollision(src1);
	}	
}

bool EntityController::HasCollided( Entity *src1, Entity *src2)
{
	Coord c1 = {src1->GetX(), src1->GetY() };
	Coord c2 = {src2->GetX(), src2->GetY()};
		
	return CalcDistance( &c1, &c2) <= src1->GetRadius() + src2->GetRadius();
}

// Entity update functions

void EntityController::Update(Entity *ent)
{
	ent->Do();
}

// Entity factory functions
void EntityController::EraseEntity(Entity *ent)
{
	ent = nullptr;
}

void EntityController::SetLevel( Level *l )
{
	level = l;
}

void EntityController::SpawnEnemies( Enemy *e )
{
	core.enemy.push_back( e );
}

void EntityController::SpawnProjectile(Projectile *type)
{
	core.ammo.push_back(type);
}

void EntityController::CreateBigAsteroid(Asteroid *ast)
{
	core.asteroid.push_back( ast );
}

void EntityController::CreateSmallAsteroid(Asteroid * ast)
{
	/*int index = astros.size() - 1;
	float X = astros[ index ]->GetX();
	float Y = astros[ index ]->GetY();
	unsigned int Radius = astros[ NAst - 1]->GetRadius();

	index++;
	astros.push_back( asteroid );
	astros[ index ]->SetPosition( X - Radius, Y - Radius );
	index++;
	astros.push_back( asteroid );
	astros[ index ]->SetPosition( X + Radius, Y + Radius );*/
}

void EntityController::SpawnAsteroid()
{	
	/*if(aSpawnTime >= aSpawnRate * 1000 )
	{
		aSpawnTime = 0;
		if( NAst < 10 )
		{
			level->ClearTrigger( false );
			CreateBigAsteroid( new BigAstro(level->GetTrigger(level->GetCurrentTrigger()).x, 
				level->GetTrigger(level->GetCurrentTrigger()).y, astros[NAst]->GetAngle()) );
			NAst = astros.size();
		}
		else
		{
			level->ClearTrigger( true );
		}
	}*/
}

void EntityController::Spawn()
{
	UpdateTimer(&eSpawnTime);
	UpdateTimer(&aSpawnTime );
	if(eSpawnTime >= eSpawnRate)
	{
		eSpawnTime = 0.0f;
		SpawnEnemies(new Enemy(core));
	}
	if(aSpawnTime >= aSpawnRate)
	{
		aSpawnTime = 0.0f;
		SpawnAsteroid();
	}
}

bool EntityController::Kill(Entity *ent)
{
	// Future to do's: 
	// erase() in vector is supposedly inefficient, std::replace_if supposedly better option
	//
	// std::replace_if(vector.begin(), vector.end(), boolReturningFunction(), newValue);
	// boolReturningFunction() <- could be something that checks if(health <= 0) return true;
	// newValue would be something like vector.end() since the order of entities shouldn't matter
	//
	// Could also impliment a custom method that does the same but after moving vector.end() to 
	// new index spot, would call vector.pop_back()
	ScoreController cScore;
	return ent->GetHealth() <= 0.0f;
	for( int index = 0; index < core.asteroid.size(); index++ )
	{
		float radius = core.asteroid[index]->GetRadius();
		float health = core.asteroid[index]->GetHealth();

		if( health <= 0  )
		{
			if (core.asteroid[index]->GotHitByAmmo())
			{
				cScore.Add(core.asteroid[index]->GetValue());
			}
			if( radius > 25.0f)
			{
				CreateSmallAsteroid(new SmallAstro(core));
			}
			core.asteroid.erase(core.asteroid.begin() + index);
		}
	}
	for( unsigned int i = 0; i < core.enemy.size(); i++)
	{
		if(core.enemy[ i ]->GetHealth() <= 0.0f)
		{
			if( core.enemy[ i ]->GotHitByAmmo() )
			{
				cScore.Add( core.enemy[ i ]->GetValue() );
			}
			core.enemy.erase(core.enemy.begin() + i);
		}
	}			
}

// Entity utility functions
void EntityController::UpdateTimer( float *eventTimer)
{
	TimerClient tc;
	*eventTimer += tc.GetFrameTime();
}

void EntityController::CheckForTriggers()
{
	/*Level::TriggerType tType = level->IsAtTrigger( cam.GetRect().x2- (SCREENWIDTH / 2), cam.GetRect().y2 - (SCREENHEIGHT / 2) ) ;
	if(tType == Level::ENEMY)
	{
		Spawn();
	}
	if(tType == Level::ASTEROID)
	{
		SpawnAsteroid();
	}
	if(tType == Level::BOSS)
	{
		isAtBoss = true;
	}*/
}

bool EntityController::IsInView( Entity *object )
{
	/*if( object->GetX() - object->GetRadius() >  cam.GetRect().x2||
		object->GetX() + object->GetRadius() <= cam.GetRect().x1 ||
		object->GetY() - object->GetRadius() >  cam.GetRect().y2 ||
		object->GetY() + object->GetRadius() <= cam.GetRect().y1)
	{
		return false;
	}*/

	return true;
}
