#pragma once

#include "Entity.h"
#include <vector>
#include "Asteroid.h"
#include "Ship.h"
#include "Camera.h"

class StateCore;

class EntityController
{
public:
	friend StateCore;
	EntityController(StateCore &core);
	~EntityController();
	void Spawn();
	bool Kill(Entity *ent);
	void SpawnAsteroid();
	void SpawnProjectile(Projectile *pType);
	void SpawnEnemies(Enemy * eType);

	// Collision function
	void CheckCollision(Entity *src1, Entity *src);

	// Entity update Methods
	void Update(Entity *ent);

private:
	// Private Methods
	bool HasCollided(Entity *src1, Entity *src2);

	// Utility functions
	void UpdateTimer( float *eventTimer);
	void CheckForTriggers();
	bool IsInView( Entity *e);
	void SetLevel( Level *l );

	// Factory functions
	void EraseEntity(Entity *ent);
	void CreateBigAsteroid(Asteroid * ast);
	void CreateSmallAsteroid(Asteroid *ast);
	
	// Private members
private:
	Level *level;
	StateCore &core;
	unsigned int playerScore;
	unsigned int lIndex;
	unsigned int currentEnemyCount;
	unsigned int NAst;
	bool isAtBoss;
	bool gameStarted;
	
	const float aSpawnRate, eSpawnRate;
	float eSpawnTime, aSpawnTime;
};