#include "input.h"
#include <assert.h>


BOOL CALLBACK DIEnumDevices( LPCDIDEVICEINSTANCE lpddi, LPVOID lpvRef )
{
	// some complex pointer stuff huh xD
	// i pretty much convert the dwords to pointers
	LPDIRECTINPUTDEVICE8* lpPad = (LPDIRECTINPUTDEVICE8*)((DWORD*)lpvRef)[1];
	((LPDIRECTINPUT8)(*(DWORD*)lpvRef))->CreateDevice( lpddi->guidInstance, lpPad, NULL );

	DIDEVCAPS diCaps = *(LPDIDEVCAPS)(((DWORD*)lpvRef)[2]);
	ZeroMemory( &diCaps, sizeof(DIDEVCAPS) );
	(*lpPad)->GetCapabilities( &diCaps );
	if( diCaps.dwAxes < 4 )
		return DIENUM_CONTINUE;
	
	return DIENUM_STOP;
}

Input::Input(HWND hWnd)
	: hwnd( hWnd ),
	  mX(0),
	  mY(0),
	  CLF(false)
{
	HRESULT hr = 0;
	hr = DirectInput8Create( GetModuleHandle(NULL), DIRECTINPUT_VERSION, IID_IDirectInput8, (void**)&lpdi, NULL );
	assert( hr >= 0 );

	// Initialize Keyboard
	ZeroMemory( keys, sizeof(BYTE)*256 );
	hr = lpdi->CreateDevice( GUID_SysKeyboard, &pKeyB, NULL );
	pKeyB->SetDataFormat( &c_dfDIKeyboard );
	pKeyB->SetCooperativeLevel( hwnd, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE );
	
	DIPROPDWORD dipdKeyb;
	dipdKeyb.diph.dwSize = sizeof(DIPROPDWORD);
	dipdKeyb.diph.dwHeaderSize = sizeof(DIPROPHEADER);
	dipdKeyb.diph.dwObj = 0;
	dipdKeyb.diph.dwHow = DIPH_DEVICE;
	dipdKeyb.dwData = sizeof(DIDEVICEOBJECTDATA);
	pKeyB->SetProperty( DIPROP_BUFFERSIZE, &dipdKeyb.diph );

	// Initialize Joystick
	pPad = nullptr;
	hr = lpdi->CreateDevice( GUID_Joystick, &pPad, NULL);
	if(pPad)
	{
		ZeroMemory( &diCaps, sizeof(DIDEVCAPS) );
		diCaps.dwSize = sizeof(DIDEVCAPS);
		hr = pPad->GetCapabilities( &diCaps );

		// set dead zone	
		ZeroMemory( &dipdw, sizeof(dipdw) );
		dipdw.diph.dwSize = sizeof(dipdw);
		dipdw.diph.dwHeaderSize = sizeof(dipdw.diph);
		dipdw.diph.dwHow = DIPH_DEVICE;

		// set buffer size
		dipdw.dwData = sizeof(DIDEVICEOBJECTDATA);
		pPad->SetProperty( DIPROP_BUFFERSIZE, &dipdw.diph );
	
		pPad->SetDataFormat( &c_dfDIJoystick );
		pPad->SetCooperativeLevel( hwnd, DISCL_FOREGROUND|DISCL_EXCLUSIVE );
		pPad->Acquire();
	
		ZeroMemory( &diJState, sizeof(diJState) );
	}
	// Initialize Mouse
	ZeroMemory( &dims, sizeof(dims) );
	
	hr = lpdi->CreateDevice( GUID_SysMouse, &pMouse, NULL );
	pMouse->SetDataFormat( &c_dfDIMouse2 );
	pMouse->SetCooperativeLevel( hwnd, DISCL_FOREGROUND | DISCL_EXCLUSIVE );
	
	DIPROPDWORD dipd;
	dipd.diph.dwSize = sizeof(DIPROPDWORD);
	dipd.diph.dwHeaderSize = sizeof(DIPROPHEADER);
	dipd.diph.dwObj = 0;
	dipd.diph.dwHow = DIPH_DEVICE;
	dipd.dwData = sizeof(DIDEVICEOBJECTDATA);
	pMouse->SetProperty( DIPROP_BUFFERSIZE, &dipd.diph );

}

Input::~Input()
{
	if( pKeyB )
	{
		pKeyB->Unacquire();
		pKeyB->Release();
	}
	pKeyB = nullptr;

	if( pPad )
	{
		pPad->Unacquire();
		pPad->Release();
	}
	pPad = nullptr;

	if( pMouse )
	{
		pMouse->Unacquire();
		pMouse->Release();
	}
	pMouse = nullptr;

	if(lpdi)
	{
		lpdi->Release();
	}
	lpdi = nullptr;
}

void Input::Poll()
{
	pKeyB->Acquire();
	pKeyB->Poll();
	pKeyB->GetDeviceState( sizeof(BYTE)*256, keys );

	if(pPad)
	{
		pPad->Acquire();
		pPad->Poll();
		pPad->GetDeviceState(sizeof(diJState), &diJState );
	}

	pMouse->Acquire();
	pMouse->Poll();
	pMouse->GetDeviceState( sizeof(DIMOUSESTATE2), &dims );

}

// Keyboard functions
// use DIK_XXX for key
bool Input::KeyIsPressed( unsigned char key )
{
	return keys[key] == 0x80;
}

char Input::ReadKey()
{
	DWORD dw = 1;
	DIDEVICEOBJECTDATA didod;	
	pKeyB->GetDeviceData( sizeof(DIDEVICEOBJECTDATA), &didod, &dw, 0 );
	return dw ? didod.dwOfs : 0;
}

bool Input::PeekKey()
{
	DWORD dw = 1;
	pKeyB->GetDeviceData( sizeof(DIDEVICEOBJECTDATA), NULL, &dw, DIGDD_PEEK );
	return dw;
}

// Joystick functions
void Input::RemoveDeadZone(float* axis)
{
	if(*axis < 0.05f && *axis > -0.05f)
	{
		*axis = 0.0f;
	}
}

float Input::GetJoyX()
{
	float temp = (((float)diJState.lX - 32767) / 32767);
	RemoveDeadZone(&temp);
	return temp;
}

float Input::GetJoyY()
{
	float temp = (((float)diJState.lY - 32767) / 32767);
	RemoveDeadZone(&temp);
	return temp;
}

float Input::GetJoyZ()
{
	return ((float)diJState.rglSlider[0] - 32767) / 32767;
}

float Input::GetJoyR()
{
	return ((float)diJState.lRz - 32767) / 32767;
}

bool Input::GetJoyButton(BYTE btn)
{
	return diJState.rgbButtons[btn] & 0x80;
}

bool Input::CheckJoystick()
{
	return pPad != NULL;
}

// Mouse functions
short Input::GetMouseX()
{
	mX += dims.lX * 0.5f;
	ClipAxis( clipWidth, &mX);
	return mX;
}

short Input::GetMouseY()
{
	mY += dims.lY * 0.5f;
	ClipAxis( clipHeight, &mY);
	return mY;
}

// Z in this case is the mouse wheel
short Input::GetMouseWheel()
{
	return dims.lZ += dims.lZ;
}

// use DIMOFS_XXX for btn
bool Input::BtnIsPressed( BYTE btn )
{
	return dims.rgbButtons[btn] & 0x80;
}

// Next 2 functions are for buffered data, they might be useful for something
char Input::Read()
{
	DWORD dw = 1;
	DIDEVICEOBJECTDATA didod;
	pMouse->GetDeviceData( sizeof(DIDEVICEOBJECTDATA), &didod, &dw, 0 );
	return dw ? didod.dwOfs : 0;
}

bool Input::Peek()
{
	DWORD dw = 1;
	pMouse->GetDeviceData( sizeof(DIDEVICEOBJECTDATA), NULL, &dw, DIGDD_PEEK );
	return dw;
}

void Input::ClipAxis(unsigned int maxClipSize, long* axis)
{
	if(*axis < 0)
	{
		*axis = 0;
	}
	if(*axis >= maxClipSize)
	{
		*axis = maxClipSize - 1;
	}
}

void Input::SetClip( unsigned int sX, unsigned int sY )
{
	clipWidth = sX;
	clipHeight = sY;
}

void Input::GetAxes(float *x, float *y)
{
	float tempX = 0;
	float tempY = 0;
	if( CheckJoystick() )
	{
		tempX = GetJoyX();
		tempY = GetJoyY();
	}
	// W or UpArrow
	if( KeyIsPressed( DIK_W ) || KeyIsPressed( DIK_UP ) )
	{
		*y = -1.0f;
	}
	// S or DownArrow
	else if( KeyIsPressed( DIK_S ) || KeyIsPressed( DIK_DOWN ) )
	{
		*y = 1.0f;
	}
	else
	{
		*y = tempY;
	}
	// A or LeftArrow
	if( KeyIsPressed( DIK_A ) || KeyIsPressed( DIK_LEFT ) )
	{
		*x = -1.0f;
	}
	// D or RightArrow
	else if( KeyIsPressed( DIK_D ) || KeyIsPressed( DIK_RIGHT ) )
	{
		*x = 1.0f;
	}
	else
	{
		*x = tempX;
	}

}

bool Input::Firing()
{
	// Fire = Spacebar, Left Mouse Button, Joystick button 0
	if( KeyIsPressed( DIK_SPACE) || BtnIsPressed( DIMOFS_BUTTON0 - DIMOFS_BUTTON0  ) || GetJoyButton( DIJOFS_BUTTON0 - DIJOFS_BUTTON0 ) )
	{
		return true;
	}
	return false;
}

bool Input::PauseGame()
{
	if( KeyTyped( DIK_F10 ) )
	{
		return true;
	}
	return false;
}

bool Input::LeftButtonClicked()
{	
	if(CLF && !BtnIsPressed( 0 ))
	{
		CLF = false;
		return true;
	}
	else if( !CLF && BtnIsPressed( 0 ) )
	{
		CLF = true;
	}
	return false;
}

bool Input::KeyTyped( unsigned char code)
{
	if(plf && !KeyIsPressed(code) )
	{
		plf = false;
		return true;
	}
	else if(!plf && KeyIsPressed(code) )
	{
		plf = true;
	}
	return false;
}
