#include "Projectiles.h"
#include "StateCore.h"

Projectile::Projectile( Coord &pos, Coord &slope, StateCore &core )
	:
	Entity(core)
{
	health = 0.10f;
	velocity = 600;
	damage = 0.5f;
}

void Projectile::DoCollision(Entity *ent)
{
	health = 0;
	ent->ReduceHealth( damage );
	ent->SetHitByAmmo( true );
}

void Projectile::Move()
{
	float speed = CalcSpeed( velocity );
	y += speed * slope.y;
	x += speed * slope.x;
}

void Projectile::SetCamPosition( Coord c )
{
	cam = c;
}

void Projectile::SetLaunchPosition( Coord coord, Coord Slope  )
{
	x = coord.x;
	y = coord.y;
	slope = Slope;
}

bool Projectile::HasTimeToLive()
{
	if(liveTime < TTL)
	{
		liveTime = 0.0f;
		return true;
	}

	return false;
}

void Projectile::Draw()
{
	core.gfx.DrawAmmo(x, y);
}

void Projectile::Do()
{
	UpdateTime( &fireTime );
	UpdateTime( &liveTime );
	Move();	
}

Projectile::~Projectile()
{
}

// Machine Gun class
MGun::MGun( Coord pos, Coord slope, StateCore &core )
	:
	Projectile(pos, slope, core)
{
	energyUsed = 0.0f;
	damage = 0.25f;
}

void MGun::Draw()
{
	Coord res;
	Coord pos = {x, y};
	res.x = core.gfx.GetWidth();
	res.y = core.gfx.GetHeight();
	Coord c = GameToScreenCoord( pos, res, cam);
	core.gfx.DrawAmmo( c.x, c.y );	
}

// Missile Class Begin

Missile::Missile( Coord coord, Coord slope, StateCore &core )
	:
	Projectile(coord, slope, core),
	MIR( 10 ),
	explodeDuration(0.3f)
{
	TTL = 1.0f;
	targetAcquired = false;
	damage = 10;
	energyUsed = 0.0f;
}

void Missile::DecideState()
{
	if(!targetAcquired)
	{
		if(Fired)
		{
			mState = Acquire;
		}
		else
		{
			mState = None;
		}
	}
	else if(LaunchTimer < TTL * 1000 && targetAcquired)
	{
		mState = Launched;
	}
	else
	{
		if( ExplodeTimer < explodeDuration * 1000)
		{
			mState = Exploded;
		}
		else
		{
			mState = Reset;
		}
	}
}

void Missile::DoState( int tX, int tY, bool canFire )
{
	Fired = canFire;
	DecideState();
	switch(mState)
	{
	case Acquire:
		AcquireTarget(tX, tY);
		break;
	case Launched:
		LaunchMissiles();
		break;
	case Exploded:
		Explode();
		break;
	case Reset:
		ResetMissile();
		break;
	
	}
}

void Missile::AcquireTarget(  int tX,  int tY )
{
	// Randomize X, Y +/- 100 from player position
	x = (rand() % 200 - 100) + tX;
	y = (rand() % 200 - 100) + tY;
	targetAcquired = true;
}

void Missile::LaunchMissiles()
{
	UpdateTime(&LaunchTimer);
}

void Missile::Explode()
{
	UpdateTime(&ExplodeTimer);
}

void Missile::ResetMissile( )
{
	x = 0;
	y = 0;
	ExplodeTimer = 0;
	LaunchTimer = 0;
	targetAcquired = false;
}

bool Missile::HasExploded()
{
	return mState == Exploded;
}

int Missile::GetMIR() const
{
	return MIR;
}

void Missile::Draw()
{
	switch( mState )
	{
	case Launched:
		core.gfx.DrawCircle( x, y, MIR, core.gfx.FILLCOLOR_XRGB(0,255,0 ));
		break;
	case Exploded:
		core.gfx.DrawCircle( x, y, MIR, core.gfx.FILLCOLOR_XRGB(255,0,0 ));
		break;
	}
}

// EnergyBall class
EnergyBall::EnergyBall(Coord pos, Coord slope, StateCore &core)
	:
	Projectile(pos, slope, core)
{
	health = 1.0f;
	damage = 1.0f;
	energyUsed = 2.0f;
}

// Laser Class
Laser::Laser(Coord pos, Coord slope, StateCore &core)
	:
	Projectile(pos, slope, core)
{
	health = 0;
	damage = 1.0f;
	energyUsed = 4.0f;
}

