#pragma once

#include <vector>
#include <stdlib.h>
#include "Entity.h"
#include "Calculations.h"

class Projectile : public Entity
{
public:

	Projectile( Coord &pos, Coord &slope, StateCore &core );
	virtual ~Projectile();

	void Move();
	bool leavesScreen();
	bool HasTimeToLive();
	void SetLaunchPosition( Coord coord, Coord slope );
	void SetCamPosition( Coord c);
	void Do();
	virtual void Draw();
	void DoCollision(Entity *ent);
	float GetEnergyUsed() const;
protected:
	float TTL;
	Coord slope;
	Coord cam;
	float liveTime, fireTime;			// Pass to UpdateTime(&liveTime) or use &fireTime  
										// When liveTime or fireTime reaches Firerate or TTL set them to 0.0f
	float energyUsed;
};

class MGun : public Projectile
{
public:
	MGun( Coord coord, Coord slope, StateCore &core );
	virtual void Draw();
};

class EnergyBall : public Projectile
{
public:
	EnergyBall( Coord coord, Coord slope, StateCore &core  );
	virtual void Draw() {}; // Fix later
};

class Laser : public Projectile
{
public:
	Laser();
	Laser( Coord coord, Coord slope, StateCore &core  );
	virtual void Draw(){}; // Fix later
};

class Missile : public Projectile
{
public:
	enum State
	{
		None,
		Acquire,
		Launched,
		Exploded,
		Reset
	};
	Missile( Coord coord, Coord slope, StateCore &core);
	void DoState( int targetX,  int targetY, bool canFire);
	void SetMissileState( State state );
	int GetMIR() const;
	bool HasExploded();
private:
	void DecideState();
	void DestroyMissiles();
	void Explode();
	void ResetMissile();
	void LaunchMissiles();
	void AcquireTarget( int targetX,  int targetY);
	void Draw();

	State mState;
	float LaunchTimer, ExplodeTimer, frameTimer;
	const float explodeDuration;
	const float MIR;									//Missile Impact Radius
	bool Fired, targetAcquired;
};

