#pragma once

#include <vector>

#include "Input.h"
#include "Shield.h"
#include "WeaponController.h"

class Ship : public Entity
{
public:
	Ship(StateCore &core);
	virtual ~Ship();

	enum ShipState
	{
		Moving,
		Firing,
		Dead
	};

	struct Vertices
	{
		float vx, vy;
	};

	// Helper functions
	/*void SetClip( unsigned int x, unsigned y, unsigned int x2, unsigned int y2 );
	void SetScreenRes( unsigned int x, unsigned int y);*/
	void Do() = 0;
protected:
	unsigned int numVerts;
	Vertices* verts;

};

class Player: public Ship
{
public:
	Player();
	Player( Input &user, StateCore &core);
	~Player();
	void Do();
	void DoCollision(Entity *ent);
	void Draw();
	WeaponController *GetWC();
private:
	void Move();
	void Fire(Coord pos);
	void Die();
	void DecideState( );
	void Clip( );

private:
	WeaponController wc;
	float fireRate, fireTime;
	int lives;
	ShipState state;
	Input &user;
	Shield shield;
	unsigned int energy;

};

class Enemy: public Ship
{
public:
	Enemy( StateCore &core);
	virtual ~Enemy();
	void Move();
	void Fire();
	void Die();
	void Do();
	void SetSpawnPoint( unsigned int X, unsigned int Y );
	void AdjustWaypoints( float offSet );
	virtual void CheckforWayPoint();
	void CalculatePath(Ship::Vertices* ePos, const Ship::Vertices* pPos);

protected:
	unsigned int NPoints;
	unsigned int CurPoint;
	float rise, run, slope, dist;
	Vertices* Points;
	Vertices* Nextp;
	ShipState state;
	float maxSpeed;
};

class Enemy1: public Enemy
{
public:
	Enemy1(StateCore &core);
};

class Enemy2: public Enemy
{
public:
	Enemy2(StateCore &core);
};

class Enemy3: public Enemy
{
public:
	Enemy3(StateCore &core);
};

class Enemy4: public Enemy
{
public:
	Enemy4(StateCore &core);
};

class Enemy5: public Enemy
{
public:
	Enemy5(StateCore &core);
};

class Boss1: public Enemy
{
public:
	enum State
	{
		Attack,
		RegenMissiles,
		Idle
	};
	Boss1(StateCore &core);
	void Do();

	// int GetMissileRad();
	// bool MissileExploded( unsigned int i );
	float GetMissileDamage();

private:
	void Fire();
	void DecideState();
	void MissilesRegen();
	float temp;						// stores progressive time between calls for event handling

	float LaunchTimer, RegenTimer;	// Event timer triggers

	State BState;
	int pX, pY;						// playerX and playerY to pass to Missile class
	const float FireRate, RegenRate;
	unsigned int NMissiles;			// Number Of Missiles
	unsigned int MissilesFired;		// Counter for firing missiles and event handling
	unsigned int mCount;
	bool readyToFire;
	Shield shield;
};

class Boss2: public Enemy
{
public:
	enum bossState
	{
		Raming,
		None
	};
	Boss2(StateCore &core);
	void Do();
	float GetPlayerX();
	float GetPlayerY();
	void SetPlayerPos( int X, int Y );
	void Draw();
private:
	void CheckforWayPoint();
	void TransitionState();
	bossState bossState;

	const float ramCooldown;
	float px,py, ramCooldownTime;
};
