#include "Weapon.h"
#include "StateCore.h"

Weapon::Weapon(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	unlocked(unlock),
	have(have),
	curlevel(level),
	name(name),
	core(core),
	nUpgrades(5)
{
	fireRate = 2;
	fireTimer = 0;
	dummyPos.x = 0;
	dummyPos.y = 0;
	dummySlope.x = 0;
	dummySlope.y = 0;
	angle[0] = 360;
	angle[1] = 340;
	angle[2] = 20;
	angle[3] = 320;
	angle[4] = 40;
}

Weapon::~Weapon()
{
	if(projectileType)
	{
		delete projectileType;
		projectileType = nullptr;
	}
}

void Weapon::Fire( Coord pos)
{
	UpdateTimer( &fireTimer );
	if(fireTimer >= fireRate )
	{
		fireTimer = 0.0f;
		for(int i = 0; i < curlevel; i++)
		{
			Coord slope = CalcAngleToSlope(angle[i]);
			projectileType->SetLaunchPosition(pos, slope);
			core.ammo.push_back(new Projectile(*projectileType) );
		}
	}
}

void Weapon::UpdateTimer( float *eventTimer )
{
	TimerClient tc;
	*eventTimer += tc.GetFrameTime() / 1000;
}

ECannon::ECannon(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	Weapon(core, unlock, have, level, name, cost)
{
	projectileType = new EnergyBall(dummyPos, dummySlope, core);
}

ECannon::~ECannon()
{
}

LaserWeap::LaserWeap(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	Weapon(core, unlock, have, level, name, cost)
{
	projectileType = new Laser(dummyPos, dummySlope, core);
}

LaserWeap::~LaserWeap()
{
	if(projectileType)
	{
		delete projectileType;
		projectileType = nullptr;
	}	
}

Blaster::Blaster(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	Weapon(core, unlock, have, level, name, cost)
{
	projectileType = new Projectile(dummyPos, dummySlope, core);
	fireRate = 0.5f;
}

Blaster::~Blaster()
{
	if(projectileType)
	{
		delete projectileType;
		projectileType = nullptr;
	}
}

MachineGun::MachineGun(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	Weapon(core, unlock, have, level, name, cost)
{
	projectileType = new MGun(dummyPos, dummySlope, core);
	fireRate = 0.16f;
}

MachineGun::~MachineGun()
{
	if(projectileType)
	{
		delete projectileType;
		projectileType = nullptr;
	}
}

MLauncher::MLauncher(StateCore &core, bool unlock, bool have, unsigned int level, std::string name, unsigned int cost)
	:
	Weapon(core, unlock, have, level, name, cost)
{
	projectileType = new Projectile(dummyPos, dummySlope, core);
	fireRate = 0.5f;
}

MLauncher::~MLauncher()
{
	if(projectileType)
	{
		delete projectileType;
		projectileType = nullptr;
	}
}

